Placement

Enum Placement 

pub enum Placement {
    TopStart,
    TopCenter,
    TopEnd,
    BottomStart,
    BottomCenter,
    BottomEnd,
    LeftStart,
    LeftCenter,
    LeftEnd,
    RightStart,
    RightCenter,
    RightEnd,
}
Defines the preferred side and alignment of the floating element relative to its trigger.

Variants



TopStart



TopCenter



TopEnd



BottomStart



BottomCenter



BottomEnd



LeftStart



LeftCenter



LeftEnd



RightStart



RightCenter



RightEnd

Implementations

Source

impl Placement

pub fn is_vertical(&self) -> bool

Returns true if the placement is on the Top or Bottom side.

pub fn is_top(&self) -> bool

Returns true if the side is Top.

pub fn is_left(&self) -> bool

Returns true if the side is Left.

pub fn get_modifier(&self) -> PlacementModifier

Returns the [PlacementModifier] (Start, Center, or End) for the current placement.