pub fn use_scroll_state() -> Signal<Option<ScrollState>>Expand description
A shorthand hook to access the current ScrollState from the context.
Returns a Signal containing the dimensions and scroll offsets of the nearest ScrollableView.
pub fn use_scroll_state() -> Signal<Option<ScrollState>>A shorthand hook to access the current ScrollState from the context.
Returns a Signal containing the dimensions and scroll offsets of the nearest ScrollableView.