pub enum Placement {
TopStart,
TopCenter,
TopEnd,
BottomStart,
BottomCenter,
BottomEnd,
LeftStart,
LeftCenter,
LeftEnd,
RightStart,
RightCenter,
RightEnd,
}Expand description
Defines the preferred side and alignment of the floating element relative to its trigger.
Variants
TopStart
TopCenter
TopEnd
BottomStart
BottomCenter
BottomEnd
LeftStart
LeftCenter
LeftEnd
RightStart
RightCenter
RightEnd
Implementations
Sourceimpl Placement
impl Placement
Sourcepub fn is_vertical(&self) -> bool
pub fn is_vertical(&self) -> bool
Returns true if the placement is on the Top or Bottom side.
Sourcepub fn get_modifier(&self) -> PlacementModifier
pub fn get_modifier(&self) -> PlacementModifier
Returns the [PlacementModifier] (Start, Center, or End) for the current placement.