pub struct FloatingOptions {
pub middleware: Vec<Middleware>,
pub offset: OffsetOptions,
pub padding: f64,
pub placement: Placement,
}Expand description
Configuration for the floating position calculation.
Fields
middleware: Vec<Middleware>List of Middleware strategies to apply.
offset: OffsetOptionsDistance between the trigger and the floating element in pixels.
padding: f64Distance between the floating element and the scrollable container edges.
placement: PlacementThe preferred Placement strategy.
Implementations
Sourceimpl FloatingOptions
impl FloatingOptions
Sourcepub fn can_flip(&self) -> bool
pub fn can_flip(&self) -> bool
Returns true if the Middleware::Flip strategy is enabled.
Sourcepub fn can_shift(&self) -> bool
pub fn can_shift(&self) -> bool
Returns true if the Middleware::Shift strategy is enabled.